@@ -8,19 +8,22 @@ use strict;
 
 package XML::Compile;
 use vars '$VERSION';
-$VERSION = '0.56';
+$VERSION = '0.57';
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
 use XML::LibXML;
+use XML::Compile::Util qw/:constants/;
 
 use File::Spec     qw();
 
 __PACKAGE__->knownNamespace
- ( 'http://www.w3.org/XML/1998/namespace' => '1998-namespace.xsd'
- , 'http://www.w3.org/1999/XMLSchema'     => '1999-XMLSchema.xsd'
- , 'http://www.w3.org/1999/part2.xsd'     => '1999-XMLSchema-part2.xsd'
- , 'http://www.w3.org/2000/10/XMLSchema'  => '2000-XMLSchema.xsd'
- , 'http://www.w3.org/2001/XMLSchema'     => '2001-XMLSchema.xsd'
+ ( &XMLNS       => '1998-namespace.xsd'
+ , &SCHEMA1999  => '1999-XMLSchema.xsd'
+ , &SCHEMA2000  => '2000-XMLSchema.xsd'
+ , &SCHEMA2001  => '2001-XMLSchema.xsd'
+ , &SCHEMA2001i => '2001-XMLSchema-instance.xsd'
+ , 'http://www.w3.org/1999/part2.xsd'
+                => '1999-XMLSchema-part2.xsd'
  );
 
 __PACKAGE__->addSchemaDirs($ENV{SCHEMA_DIRECTORIES});
@@ -115,8 +118,8 @@ sub dataToXML($)
 
     my $data = "$thing";
     $data = substr($data, 0, 39) . '...' if length($data) > 40;
-    mistake __x"don't known how to interpret XML data\n   {data}"
-          , data => $data;
+    error __x"don't known how to interpret XML data\n   {data}"
+       , data => $data;
 }
 
 sub _parse($)
